@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: email-validate
 version: 2.2.0
-id: email-validate-2.2.0-ae0abf871e42011586547a4481d3ce69
-key: email_FBskWExVbGsKLO6Poucc1c
+id: email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
+key: email_CQXkJx3ILx16knsHT8WvIg
 license: BSD3
 maintainer: George Pollard <porges@porg.es>
 stability: experimental
@@ -20,9 +20,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/email-validate-2.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/email-validate-2.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/email-validate-2.2.0
-hs-libraries: HSemail-validate-2.2.0-FBskWExVbGsKLO6Poucc1c
+hs-libraries: HSemail-validate-2.2.0-CQXkJx3ILx16knsHT8WvIg
 depends:
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
